# -*- rpm-spec -*-
# $Id: kernel-image-std26-up.spec,v 1.35 2004/08/18 12:18:03 vsu Exp $
#

# Version options
%define kernel_base_version	2.6.8
%define kernel_extra_version	%nil
# Numeric extra version scheme developed by Alexander Bokovoy:
# 0.0.X -- preX
# 0.X.0 -- rcX
# 1.0.0 -- release
%define kernel_extra_version_numeric 1.0.0
%define krelease alt9

%define base_flavour	std26
%define flavour		%base_flavour-up

# Build options
# You can change compiler version by editing this line:
%define kgcc_version	3.3

# Enable/disable SGML docs formatting
%def_enable docs

# Fixes:
%add_patch_list kernel-fix-build
%add_patch_list kernel-fix-core
%add_patch_list kernel-fix-acpi
%add_patch_list kernel-fix-fs
%add_patch_list kernel-fix-drivers-net
%add_patch_list kernel-fix-drivers-scsi
%add_patch_list kernel-fix-drivers-usb
%add_patch_list kernel-fix-drivers-ide
%add_patch_list kernel-fix-security

# Feathures:

%add_patch_list kernel-feat-drivers-video-splash
%add_patch_list kernel-feat-drivers-input
%add_patch_list kernel-feat-drivers-lirc
%add_patch_list kernel-feat-drivers-pktcdvd
%add_patch_list kernel-feat-fs-squashfs
%add_patch_list	kernel-feat-net-ppp-mppe

# imz: Unicode support in VT/console
#add_patch_list kernel-feat-drivers-console-unicode
# Although this patch changes the interface between the kernel and loadkeys,
# I do not put a Conflicts for the old console-tools here,
# because the old loadkeys works fine the new kernel interface.

## Don't edit below this line ##################################

%define	kversion %kernel_base_version%kernel_extra_version

Name: kernel-image-%flavour
Version: %kversion
Release: %krelease

Summary: The Linux kernel (the core of the Linux operating system)
License: GPL
Group: System/Kernel and hardware
Url: http://www.kernel.org/
Packager: Anton Farygin <rider@altlinux.com>

Source1: config-%kernel_base_version-%flavour

ExclusiveOS: Linux

BuildRequires: coreutils dev86 bzip2 make tar flex
BuildRequires: rpm >= 4.0.2-75 libdb4-devel
BuildRequires: gcc%kgcc_version
BuildRequires: kernel-source-%{kernel_base_version} = %{kernel_extra_version_numeric}
BuildRequires: kernel-build-tools >= 0.7, modutils >= 2.4.27-alt1
BuildRequires: %get_patch_list

%if_enabled docs
BuildRequires: docbook-utils transfig ghostscript
%endif

%if_enabled ccache
BuildRequires: ccache
%endif

%ifdef use_ccache
BuildRequires: ccache
%endif

Requires: bootloader-utils >= 0.3-alt1, modutils >= 2.4.27-alt1, mkinitrd >= 1:2.9.1-alt1, startup >= 0.8.3-alt1
Provides: kernel = %kversion
Provides: alsa = 1.0.3

Prereq:		coreutils
Prereq:		modutils >= 2.4.27
Prereq:		mkinitrd >= 1:2.9.1-alt1
ExclusiveArch:	%ix86

%description
This package contains the Linux kernel that is used to boot and run
your system. It contains few device drivers for specific hardware.
Most hardware is instead supported by modules loaded after booting.
Patches included:%format_patch_list

%package -n kernel-headers-%flavour
Summary: Header files for the Linux kernel
Group: System/Kernel and hardware
Requires: kernel-headers-common >= 1.1.5
Provides: kernel-headers

%description -n kernel-headers-%flavour
These are the C header files for the Linux kernel, which define
structures and constants that are needed when building most standard
programs under Linux, as well as to rebuild the kernel.
Patches included:%format_patch_list

%package -n kernel-headers-modules-%flavour
Summary: Headers and other files needed for build kernel modules
Group: System/Kernel and hardware
Requires: kernel-headers-%flavour = %version-%release
Requires: gcc%kgcc_version

%description -n kernel-headers-modules-%flavour
These are the C headers and other files from the Linux kernel source tree, which define
structures and constants that are needed when building kernel modules only. 
Don't use it for any purposes except building a kernel modules.

%package -n kernel-doc-%base_flavour
Summary: Linux kernel %kversion documentation
Group: System/Kernel and hardware

%description -n kernel-doc-%base_flavour
This package contains documentation files for ALT Linux kernel packages:
 * kernel-image-%base_flavour-up-%kversion-%krelease
 * kernel-image-%base_flavour-smp-%kversion-%krelease

%prep

%setup -cT -n kernel-image-%flavour-%kversion-%krelease

%__rm -rf kernel-source-%kernel_base_version

%__tar -jxf %kernel_src/kernel-source-%kernel_base_version.tar.bz2

%setup -D -T -n kernel-image-%flavour-%kversion-%krelease/kernel-source-%kernel_base_version

echo "patches = %_patch_list"

%apply_patches 2.6

# this file should be usable both with make and sh (for broken modules
# which do not use the kernel makefile system)
echo 'export GCC_VERSION=%kgcc_version' > gcc_version.inc

%__subst 's/EXTRAVERSION[[:space:]]*=.*/EXTRAVERSION = %kernel_extra_version-%flavour-%krelease/g' Makefile
%__subst 's/CC.*$(CROSS_COMPILE)gcc/CC		= gcc-%kgcc_version/g' Makefile
# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -delete -or -name "*~" -delete

%build

KERNEL_BUILD_DIR=`pwd`

KernelVer=%kversion-%flavour-%krelease

echo "Building Kernel $KernelVer"

%__cp -vf %SOURCE1 arch/%base_arch/defconfig

%make_build mrproper

%make_build oldconfig

### It's a hack, but a useful hack:
cmp -s .config %SOURCE1 || %__cp -vf .config %SOURCE1

%make_build include/linux/version.h

%make_build V=1 bzImage

%make_build V=1 modules

echo "Kernel built $KernelVer"

%if_enabled docs
# psdocs, pdfdocs don't work yet
%make_build htmldocs
%endif

%install

KernelVer=%kversion-%flavour-%krelease

%__mkdir -p %buildroot/boot
%__install -m644 System.map %buildroot/boot/System.map-$KernelVer
%__install -m644 arch/i386/boot/bzImage %buildroot/boot/vmlinuz-$KernelVer
%__install .config %buildroot/boot/config-$KernelVer

%__make modules_install INSTALL_MOD_PATH=%buildroot

%__install -d %buildroot%_prefix/include/linux-%version-%flavour/include

pushd include
%__cp -a . %buildroot%_prefix/include/linux-%version-%flavour/include
popd

# drivers-headers install
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/scsi
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/char/drm
%__cp -a ./drivers/scsi/{{scsi,hosts,scsi_obsolete,scsi_typedefs}.h,scsi_module.c} \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/scsi/
%__cp -a ./drivers/char/drm/{drm,drm_os_linux,drmP,drm_proc}.h \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/char/drm/
pushd %buildroot%_prefix/src/linux-%version-%flavour
%__ln_s -f ../../include/linux-%version-%flavour/include ./include
popd

#%__install -d ${RPM_BUILD_ROOT}%_prefix/src/linux-%version-%flavour/drivers/media/video
#%__cp -a ./drivers/addon/bttv/{{id,bttv,bttvp,audiochip,i2c-compat,tuner,bt848}.h} \
#	${RPM_BUILD_ROOT}%_prefix/src/linux-%version-%flavour/drivers/media/video

%__install -d %buildroot%_prefix/src/linux-%version-%flavour/arch/%base_arch
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/genksyms
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/basic
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/mod
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/scripts/kconfig

%__cp -a ./Makefile %buildroot%_prefix/src/linux-%version-%flavour/
%__cp -a ./Module.symvers %buildroot%_prefix/src/linux-%version-%flavour/
%__cp -a ./arch/%base_arch/Makefile %buildroot%_prefix/src/linux-%version-%flavour/arch/%base_arch/

%__cp -a ./scripts/pnmtologo %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/mod/modpost %buildroot%_prefix/src/linux-%version-%flavour/scripts/mod/ 
%__cp -a ./scripts/mkversion %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/mod/mk_elfconfig %buildroot%_prefix/src/linux-%version-%flavour/scripts/mod/ 
%__cp -a ./scripts/kconfig/conf %buildroot%_prefix/src/linux-%version-%flavour/scripts/kconfig/ 
%__cp -a ./scripts/mkcompile_h %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/makelst %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.modpost %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.modinst %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.lib %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.clean %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile.build %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/Makefile %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/kallsyms %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/genksyms/genksyms %buildroot%_prefix/src/linux-%version-%flavour/scripts/genksyms 
%__cp -a ./scripts/basic/fixdep %buildroot%_prefix/src/linux-%version-%flavour/scripts/basic/
%__cp -a ./scripts/extract-ikconfig %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/conmakehash %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/checkversion.pl %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/checkincludes.pl %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/checkconfig.pl %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/bin2c %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 
%__cp -a ./scripts/gcc-version.sh %buildroot%_prefix/src/linux-%version-%flavour/scripts/ 


pushd %buildroot%_prefix/src/linux-%version-%flavour
ln -sf ../../include/linux-%version-%flavour/include include
popd

%__cp -a .config %buildroot%_prefix/src/linux-%version-%flavour/.config
%__cp -a gcc_version.inc %buildroot%_prefix/src/linux-%version-%flavour/
pushd %buildroot
%__rm -f %buildroot/lib/modules/$KernelVer/build
%__ln_s %_prefix/include/linux-%version-%flavour/ \
    %buildroot/lib/modules/$KernelVer/build
popd

# install documentation
%if_enabled docs
%__install -d %buildroot%_docdir/kernel-doc-%base_flavour-%version/
%__cp -a Documentation/* %buildroot%_docdir/kernel-doc-%base_flavour-%version/
%__install -d %buildroot%_docdir/kernel-doc-%base_flavour-%version/scsi/
for dir in aacraid; do
	%__install -d \
		%buildroot%_docdir/kernel-doc-%base_flavour-%version/scsi/$dir/
	%__cp -a drivers/scsi/$dir/README* \
		%buildroot%_docdir/kernel-doc-%base_flavour-%version/scsi/$dir/
done
%endif # if_enabled docs

%post
%post_kernel_image %kversion-%flavour-%krelease

%preun
%preun_kernel_image %kversion-%flavour-%krelease

%post -n kernel-headers-%flavour
%post_kernel_headers %kversion-%flavour-%krelease

%postun -n kernel-headers-%flavour
%postun_kernel_headers %kversion-%flavour-%krelease

%files
/boot/vmlinuz-%kversion-%flavour-%krelease
/boot/System.map-%kversion-%flavour-%krelease
%attr(644,root,root) /boot/config-%kversion-%flavour-%krelease
/lib/modules/%kversion-%flavour-%krelease
%exclude /lib/modules/%kversion-%flavour-%krelease/build

%files -n kernel-headers-%flavour
%dir %_prefix/include/linux-%version-%flavour
%dir %_prefix/include/linux-%version-%flavour/include
%_prefix/include/linux-%version-%flavour/include/acpi
%_prefix/include/linux-%version-%flavour/include/asm
%_prefix/include/linux-%version-%flavour/include/asm-%base_arch
%_prefix/include/linux-%version-%flavour/include/asm-generic
%_prefix/include/linux-%version-%flavour/include/config
%_prefix/include/linux-%version-%flavour/include/linux
%_prefix/include/linux-%version-%flavour/include/math-emu
%_prefix/include/linux-%version-%flavour/include/net
%_prefix/include/linux-%version-%flavour/include/pcmcia
%_prefix/include/linux-%version-%flavour/include/scsi
%_prefix/include/linux-%version-%flavour/include/video
/lib/modules/%version-%flavour-%krelease/build

%files -n kernel-headers-modules-%flavour
%_prefix/src/linux-%version-%flavour

%if_enabled docs
%files -n kernel-doc-%base_flavour
%doc %_docdir/kernel-doc-%base_flavour-%version
%endif

%changelog
* Wed Aug 18 2004 Sergey Vlasov <vsu@altlinux.ru> 2.6.8-alt9
- Added missing scripts/gcc-version.sh to kernel-headers-modules.
- Removed libkconfig.so shared library to avoid extra dependencies in packages.

* Mon Aug 16 2004 Anton Farygin <rider@altlinux.ru> 2.6.8-alt8
- 2.6.8
- added patch for fix typo in nfs code (2.6.8.1)
- updated acpi subsystem to last stable release (20040717)
- updated bootsplash

* Thu Aug 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.7-alt8
- Updated kernel-fix-security:
    + fix ppos races (CAN-2004-0415)

* Thu Jun 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.7-alt7
- 2.6.7
- updated bootsplash patch
- added kernel-fix-drivers-net:
  + 2.6_50_eql-check-null.patch: add NULL checks to the eql driver
  + 2.6_51_airo-proc-fix.patch: fix airo /proc write breakage
- added kernel-fix-drivers-usb:
  + 2.6_51_phidgetservo-fixes.patch: fix use of freed memory in PhidgetServo
    driver
  + 2.6_52_storage-jumpshot-fix.patch: fix size reporting in the Lexar Jumpshot
    CF driver; avoid "unneeded entry" message with some devices
- added kernel-fix-drivers-scsi:
  + 2.6_50_sata_sil-mod15write.patch: fix Seagate+SiI3112 mod15write bug
    workaround broken by the LBA48 optimizations

* Tue Jun 15 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt6
- kernel-fix-security added:
  + 2.6_50_fpu-exception.patch: fix FPU exception handling DoS

* Fri May 21 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt5
- updated to last kernel-fix-ide and kernel-fix-fs patches:
  + 2.6_55_reiserfs-i_size-race.patch: fix reiserfs inode size update race
    which could lead to file corruption
  + 2.6_52_no-suspend-on-reboot.patch: replaced with better fix (flush drive
    cache on reboot)
  + 2.6_51_dquot_release-oops.patch: fix dquot_release oops with quota_v1
  + 2.6_52_quota-recursion.patch: fixes quota recursion into filesystem
  + 2.6_53_quota-recursion-fix.patch: fix the recursion fix
  + 2.6_54_quota-v2-corruption.diff: fix possible quota_v2 files corruption
    when root did not have any inodes&space allocated
- added kernel-feat-pktcdvd

* Mon May 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt4
- config tuning:
    CONFIG_BLK_DEV_ATIIXP=y
    CONFIG_IP_NF_MATCH_IPRANGE=m
    CONFIG_IP_NF_MATCH_PHYSDEV=m
    * disabled debug on i2c
    * enabled ebtables
    * disabled CONFIG_FONT_MINI_4x6
    * moved CONFIG_X86_MCE_NONFATAL to modules
    * disabled CONFIG_IDEDMA_IVB
- added kernel-fix-drivers-ide (Sergey Vlasov) with:
  + 2.6_50_wcache-fixes.patch: fix write cache handling problems:
    + fix drive->wcache setting
    + send CACHE FLUSH (EXT) only if the drive claims to support it
    + fix for Maxtor disks falsely claiming CACHE FLUSH EXT support
  + 2.6_51_system_state.patch: differentiate between halt/poweroff/reboot
  + 2.6_52_no-suspend-on-reboot.patch: avoid drive spindown on reboot

* Tue May 11 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt3
- 2.6.6
- fixed depends (kernel-headers-modules)
- added kernel-fix-acpi with:
    fixes IRQ12 sharing

 
- Added kernel-feat-drivers-console-unicode by Ivan Zakharyaschev <imz@altlinux.ru>:
  fixes the imperfectness of Linux VT/console Unicode support 
  (involves a change of the kernel interface used by loadkeys, 
  but mainly is compatible with old loadkeys).

* Mon Apr 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.5-alt2
- fixed requires (kernel-headers-common >= 1.1.5), bugzilla #3892


* Mon Apr 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.5-alt1
- 2.6.5
- added squashfs patch
- enabled forcedeth driver (CONFIG_FORCEDETH=m)
- added kernel-doc-std26 package
- updated trackpoint patch
- updated splash patch


* Thu Mar 22 2004 Anton Farygin <rider@altlinux.ru> 2.6.4-alt4
- fixed requires (mkinitrd >= 2.9.1-alt1, modutils >= 2.4.27-alt1)
- some cpufreq feathures moved to modules
- enabled PF_KEYv2 socket family support
- temporary disabled software suspend
- temporary disabled PREEMPT
- updated bootsplash patch from Gentoo (with fixed kernel oops on boot)
- added Provides: alsa = 1.0.3
- added lirc modules
- disabled drm modules

* Wed Mar 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.4-alt3
- removed Provides kernel-headers-std
- fixed permissions for files into /boot

* Thu Mar 11 2004 Anton Farygin <rider@altlinux.ru> 2.6.4-alt2
- 2.6.4

* Wed Feb 18 2004 Anton Farygin <rider@altlinux.ru> 2.6.3-alt1
- 2.6.3

* Tue Feb 17 2004 Rider <rider@altlinux.ru> 2.6.2-alt2
- removed symlinking to default kernel on post-install stage

* Wed Feb  4 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.2-alt1
- 2.6.2
- CONFIG_HIGHMEM4G=y (64G caused an reboot on Centrino-based notebooks)
- CONFIG_MAGIC_SYSRQ=y

* Tue Jan 20 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.1-alt5
- evms 2.2.2
- packet CD writing support
- CD-MRW (Mt Rainier) support
- CONFIG_BLK_DEV_IDEPNP was turned off
- some headers from ./drivers/char/drm/ added to the kernel-headers-modules
- kernel-modpost package removed
- xfs bug fixed

* Sat Jan 17 2004 Gleb Stiblo <ulfr@altlinux.org> 2.6.1-alt4
- framebuffer added!
- splash added

* Thu Jan 15 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.1-alt3
- initrd size increased to 12288 Kb
- DM and EVMS fixes added
- spec sanity check: %%defattr removed

* Wed Jan  14 2004 Gleb Stiblo <ulfr@altlinux.org> 2.6.1-alt2
- some files to kernel-headers-modules
- Makefiles hacks
- initrd size increased to 8192 Kb

* Fri Jan  9 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.1-alt1
- 2.6.1
- gcc 3.3
- Default Linux Capabilities build into the kernel
- NSA SELinux Support removed

* Thu Jan  8 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.0-alt3
- kernel-fix-security patchset added (CAN-2003-0985 mremap fix and capability fix)
- NSA SELinux Support added

* Tue Dec 23 2003 Ed V. Bartosh <ed@altlinux.org> 2.6.0-alt2
- IDE chipsets are compiled into the kernel now

* Thu Dec 18 2003 Ed V. Bartosh <ed@altlinux.org> 2.6.0-alt1
- rebuild for 2.6.0 release
- fix-core and fix-fs added

* Wed Dec 17 2003 Ed V. Bartosh <ed@altlinux.org> 2.6.0test11-alt2
- symlink 'include' added to the kernel-modules-headers package

* Thu Dec  4 2003 Ed V. Bartosh <ed@altlinux.ru> 2.6.0test11-alt1
- 2.6test11
- spec improvements
- 'kernel-modpost' package added

* Sat Nov 29 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt12
- Updated kernel-fix-security:
  + fixed CAN-2003-0001, CAN-2003-0461, CAN-2003-0961

* Fri Nov 28 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt11
- Updated kernel-fix-fs:
  + fixed iso9660 mount options handling
- Added kernel-fix-security.
- Updated kernel-feat-acpi:
  + new ACPI patch (ACPI hotplug fix, pci=noacpi fix)
- Updated kernel-feat-cpufreq:
  + speedstep-smi driver fixes
- Updated kernel-feat-drivers-libata:
  + updated libata patch to 2.4.23-rc3-libata1:
    - fixed a bug which may cause some devices to "not be talked to" at probe
      time (fixed flush of Device Control register to device)
    - ServerWorks-specific tweaks
  + added Intel Software RAID (ICH5R) support (iswraid module)
- Modified security configuration:
  + Non-executable user stack area enabled (with GCC trampolines
    autodetection): CONFIG_HARDEN_STACK=y, CONFIG_HARDEN_STACK_SMART=y
  + Restricted /proc enabled: CONFIG_HARDEN_PROC=y

* Wed Nov 19 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt10
- Fixed file lists for kernel-headers-%%flavour:
  + added acpi/, crypto/, freeswan.h, freeswan/, pfkey.h, pfkeyv2.h, zlib/
- Fixed kernel-headers-modules-%%flavour dependencies.
- Modified configuration:
  - adma100, sc1200, siimage drivers are now built into the kernel (building
    IDE controller drivers as modules does not work unless the whole IDE
    subsystem is in modules too)
  - tvmixer module is not built (now it is in kernel-modules-v4l-%%flavour)
- Added kernel-fix-drivers-pnp:
  + fixed problems with detection of some ISA PnP cards
- Updated kernel-fix-drivers-net:
  + fixed multicast list handling in the tulip driver
- Updated kernel-fix-drivers-scsi:
  + sg driver bugfix: do not accept negative sizes in SG_SET_RESERVED_SIZE
- Updates kernel-fix-fs:
  + fixed quota stats accounting bug
  + fixed races on inode deletion (could cause oops with NFS)
- Updated kernel-feat-acpi:
  + new ACPI patch (IRQ assignment fixes, poweroff fix)
- Updated kernel-feat-drivers-libata:
  + new upstream version (Promise driver bugfixes)
  + added support for Promise FastTrak 376

* Sat Nov 15 2003 Albert R. Valiev <darkstar@altlinux.ru> 2.4.22-alt9
- Added kernel-feat-driver-net-pcnet32-old patch 
- fix for vmware network card driver

* Sun Nov 09 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt8
- Updated kernel-feat-acpi (ACPI updates and fixes, Alt-SysRq poweroff fix).
- Updated kernel-feat-drivers-libata (new version, Promise SATA driver
  significantly enhanced).
- Updated kernel-fix-drivers-scsi (updated ServeRAID and MegaRAID drivers, SCSI
  blacklist updates).
- Added kernel-fix-drivers-cdrom (bugfixes).
- Updated kernel-fix-core, kernel-fix-drivers-char, kernel-fix-drivers-ide,
  kernel-fix-drivers-ieee1394, kernel-fix-drivers-net, kernel-fix-drivers-pci,
  kernel-fix-drivers-sound, kernel-fix-drivers-usb, kernel-fix-fs,
  kernel-fix-lvm, kernel-fix-net (lots of bugfixes).
- Relaxed BuildRequires (libdb4.0-devel -> libdb4-devel) (#2826).

* Sun Oct 19 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt7
- Updated kernel-feat-acpi (important bugfixes; enabled DMI info dump; moved
  ACPI BIOS date cutoff from 2001 to 2000).
- Added kernel-fix-lvm (makes LVM snapshots work with journaling FS).
- Added documentation subpackage (common for std-up and std-smp flavours).
- Added kernel-feat-libata (Serial ATA drivers). Supported devices: Intel ICH5,
  Promise FastTrak S150 TX2plus/TX4/SX4, Broadcom (Apple K2) SATA, VIA SATA.
  Silicon Image SATA support not enabled (does not work yet).
- Updated kernel-feat-i2c (2.8.1 release).

* Tue Oct 07 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt6
- updated kernel-feat-net-ppp-mppe (this version should really work)
- updated kernel-feat-crypto:
  - back to old cryptoapi from kerneli.org
- moved .config to kernel-headers-modules
- added toplevel Makefile and Rules.make to kernel-headers-modules (needed for
  compilation of some external modules)
- added kernel-feat-cpufreq (frequency/voltage scaling support)
- removed kernel-feat-bttv, kernel-feat-saa7134 (now in kernel-modules-v4l)
- removed kernel-feat-addon (no longer used)
- updated kernel-feat-acpi (more fixes)
- turned off OV511 USB camera driver (now in kernel-modules-v4l)

* Mon Sep 29 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt5
- updated kernel-fix-net:
  - hidden IGMPv3 definitions in <linux/in.h> from userspace (workaround for
    #3053)
- updated kernel-fix-drivers-usb, kernel-feat-drivers-usb:
  - lots of bugfixes and new device IDs
- updated kernel-fix-drivers-char:
  - added AGP support for Intel 875 (integrated video not supported)
- fixed kernel-headers-modules building:
  - install updated bttv headers instead of obsolete ones

* Wed Sep 24 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt4
- added kernel-feat-acpi:
    + ACPI update 20030916-2.4.22 (should fix some problems with nForce)
    + DSDT override from initrd
    + blacklist updates
- added kernel-fix-drivers-mtd, kernel-fix-drivers-sound,
  kernel-fix-drivers-video:
    + missing MODULE_LICENSE fixes
- updated kernel-fix-drivers-char:
    + fixed AGP 3.0 support for Via KT400
    + added AGP support for Intel 7x05, ATI Radeon IGP, Via CLE266
- updated kernel-fix-drivers-pci:
    + enable SMBus controller on ASUS boards
- added kernel-headers-modules-%flavour package (Rider)
- added provides: kernel24-headers (Rider)
- added kernel-feat-drivers-sound-emu10k1 (Rider)
    + update emu10k1 to 0.20a
- added drivers/media/video/ headers to kernel-headers-modules package (Rider)
- disabled 8139cp (PCI ID conflict with 8139too)
- added kernel-fix-drivers-ieee1394, kernel-fix-drivers-atm

* Thu Sep 11 2003 Anton Farygin <rider@altlinux.ru> 2.4.22-alt3
- enabled aic79xx module by default
- updated sk98lin driver for support 3c940 and other (based on sk98)  ethernet cards
- enabled CONFIG_4GB option
- build ATM support for UP kernel

* Tue Sep 09 2003 Anton Farygin <rider@altlinux.ru> 2.4.22-alt2
- fixed bug with build userspace v4l programms

* Tue Sep 02 2003 Rider <rider@altlinux.ru> 2.4.22-alt1
- update to 2.4.22
- removed ACPI patches (mainstream)
- removed O(1)sheduler

* Tue Aug 26 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt14
- played with OWL patch configs. installator should work just fine now.

* Thu Aug 14 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt13
- added Video4Linux Version 2 API patch.
- added kernel-fix-drivers-md.
- added saa7134 driver.

* Wed Aug 13 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt12
- removed percentexclude pcmcia dir.

* Mon Aug 11 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt11
- getting back bttv.

* Mon Aug 11 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt10
- upgraded patches.
- added patches:
  + kernel-fix-drivers-char
  + kernel-fix-drivers-video
- temporary removed patches:
  - kernel-feat-bttv

* Thu Aug 07 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt9
- got back all the pcmcia inkernel drivers, as 3.2.4 are considered as
  experimental.

* Thu Jul 31 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt8
- added kernel-headers to provides of kernel-headers-%{flavour}.
- replaced get_patch_list with format_patch_list.
- rebuilt with new kernel-fix-core with new dcache names patch. start-stop-daemon
  should work now.
- added asm-generic directory to headers.
- don't build pcmcia modules inside the kernel.

* Wed Jul 30 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt7
- removed iscsi patch as rider@ and ab@ suggested.

* Thu Jul 17 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt6
- Added provides kernel24
- ACPI support now included (+ kernel-feat-acpi)
- Fixed OWL security patch configuration, proc is now visible to all in
  std kernels.

* Tue Jul 15 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt5
- new patches:
  + kernel-fix-fs

* Wed Jul 09 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt4
- compiled Promise PDC drivers in kernel (satisfying request by mouse@a.r).

* Mon Jul 07 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt3
- new patches:
  + kernel-fix-drivers
  \ + ide 
    + net
    + pci 
    + scsi
    + usb
    + security-owl
  + kernel-feat
  \ + fs-ntfs
    + i2c
- fixed spec in many places
- changed /etc/apt/apt.cond.d/file filename so that kernel packages with different versions installed at one time
  don't conflict.

* Sat Jun 21 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt1
- upgraded to rc7
- applied patches:
  + kernel-fix-core
  + kernel-feat-core-O1sched
  + kernel-feat-iscsi 
  + kernel-feat-bttv
  + kernel-feat-fs-xfs
  + kernel-feat-kconfig
  + kernel-feat-addon
  + kernel-feat-crypto
  + kernel-feat-drivers-video-splash
  + kernel-feat-net-ipsec
  \ + ipsec
    + ppp-mppe

* Mon May 26 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rc1-alt3
- compile ext2 filesystem in kernel for installer needs.
- added net-ipsec and video-splash features.

* Thu May 15 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rc1-alt2
- removed crypto patch because it bugs loop filesystem. ... And added 
  it again, because it doesn't.

* Fri Apr 25 2003 Peter Novodvorsky <nidd@altlinux.com> kernel-policy-rc.2
- rc2 policy release.

